package com.hw.dms.service;

import java.util.List;
import com.hw.dms.domain.DmsPlanMaint;

/**
 * 保养计划信息Service接口
 *
 * @author xins
 * @date 2024-01-08
 */
public interface IDmsPlanMaintService
{
    /**
     * 查询保养计划信息
     *
     * @param planMaintId 保养计划信息主键
     * @return 保养计划信息
     */
    public DmsPlanMaint selectDmsPlanMaintByPlanMaintId(Long planMaintId);

    /**
     * 查询保养计划信息列表
     *
     * @param dmsPlanMaint 保养计划信息
     * @return 保养计划信息集合
     */
    public List<DmsPlanMaint> selectDmsPlanMaintList(DmsPlanMaint dmsPlanMaint);

    /**
     * 新增保养计划信息
     *
     * @param dmsPlanMaint 保养计划信息
     * @return 结果
     */
    public int insertDmsPlanMaint(DmsPlanMaint dmsPlanMaint);

    /**
     * 修改保养计划信息
     *
     * @param dmsPlanMaint 保养计划信息
     * @return 结果
     */
    public int updateDmsPlanMaint(DmsPlanMaint dmsPlanMaint);

    /**
     * 批量删除保养计划信息
     *
     * @param planMaintIds 需要删除的保养计划信息主键集合
     * @return 结果
     */
    public int deleteDmsPlanMaintByPlanMaintIds(Long[] planMaintIds);

    /**
     * 删除保养计划信息信息
     *
     * @param planMaintId 保养计划信息主键
     * @return 结果
     */
    public int deleteDmsPlanMaintByPlanMaintId(Long planMaintId);





    /**
     * 查询保养计划信息 Join detail
     *
     * @param planMaintCode 保养计划信息Code
     * @return 保养计划信息
     */
    public DmsPlanMaint selectDmsPlanMaintJoinByPlanMaintCode(String planMaintCode);
}
